"""
Structured information about a process of validating a computational model.
"""

# this file was auto-generated!

from datetime import datetime, time

from openminds.base import LinkedMetadata
from openminds.properties import Property


class ModelValidation(LinkedMetadata):
    """
    Structured information about a process of validating a computational model.
    """

    type_ = "https://openminds.ebrains.eu/computation/ModelValidation"
    context = {"@vocab": "https://openminds.ebrains.eu/vocab/"}
    schema_version = "latest"

    properties = [
        Property(
            "custom_property_sets",
            "openminds.latest.core.CustomPropertySet",
            "customPropertySet",
            multiple=True,
            unique_items=True,
            min_items=1,
            description="no description available",
            instructions="Add any user-defined parameters grouped in context-specific sets that are not covered in the standardized properties of this activity.",
        ),
        Property(
            "description",
            str,
            "description",
            formatting="text/markdown",
            multiline=True,
            description="Longer statement or account giving the characteristics of someone or something.",
            instructions="Enter a description of this activity.",
        ),
        Property(
            "end_time",
            [datetime, time],
            "endTime",
            description="no description available",
            instructions="Enter the date and/or time on when this activity ended, formatted as either '2023-02-07T16:00:00+00:00' (date-time) or '16:00:00+00:00' (time).",
        ),
        Property(
            "environment",
            ["openminds.latest.computation.Environment", "openminds.latest.core.WebServiceVersion"],
            "environment",
            required=True,
            description="no description available",
            instructions="Add the computational environment in which this computation was executed.",
        ),
        Property(
            "inputs",
            [
                "openminds.latest.computation.LocalFile",
                "openminds.latest.computation.ValidationTestVersion",
                "openminds.latest.core.File",
                "openminds.latest.core.FileBundle",
                "openminds.latest.core.ModelVersion",
                "openminds.latest.core.SoftwareVersion",
            ],
            "input",
            multiple=True,
            unique_items=True,
            min_items=1,
            required=True,
            description="Something or someone that is put into or participates in a process or machine.",
            instructions="Add all inputs used by this activity.",
        ),
        Property(
            "launch_configuration",
            "openminds.latest.computation.LaunchConfiguration",
            "launchConfiguration",
            description="no description available",
            instructions="Add the launch configuration of this computation (e.g., command-line arguments).",
        ),
        Property(
            "lookup_label",
            str,
            "lookupLabel",
            formatting="text/plain",
            description="no description available",
            instructions="Enter a lookup label for this activity that may help you to find this instance more easily.",
        ),
        Property(
            "outputs",
            [
                "openminds.latest.computation.LocalFile",
                "openminds.latest.core.File",
                "openminds.latest.core.FileBundle",
            ],
            "output",
            multiple=True,
            unique_items=True,
            min_items=1,
            required=True,
            description="Something or someone that comes out of, is delivered or produced by a process or machine.",
            instructions="Add all outputs generated by this activity.",
        ),
        Property(
            "performed_by",
            ["openminds.latest.computation.SoftwareAgent", "openminds.latest.core.Person"],
            "performedBy",
            multiple=True,
            unique_items=True,
            min_items=1,
            description="no description available",
            instructions="Add all agents that performed this activity.",
        ),
        Property(
            "recipe",
            "openminds.latest.computation.WorkflowRecipeVersion",
            "recipe",
            description="no description available",
            instructions="Add the workflow recipe version used for this computation.",
        ),
        Property(
            "resource_usages",
            ["openminds.latest.core.QuantitativeValue", "openminds.latest.core.QuantitativeValueRange"],
            "resourceUsage",
            multiple=True,
            unique_items=True,
            min_items=1,
            description="no description available",
            instructions="Enter all resources used during this computation (e.g., core-hours or energy).",
        ),
        Property(
            "score",
            float,
            "score",
            description="no description available",
            instructions="Enter the numerical score generated by this model validation.",
        ),
        Property(
            "start_time",
            [datetime, time],
            "startTime",
            required=True,
            description="no description available",
            instructions="Enter the date and/or time on when this activity started, formatted as either '2023-02-07T16:00:00+00:00' (date-time) or '16:00:00+00:00' (time).",
        ),
        Property(
            "started_by",
            ["openminds.latest.computation.SoftwareAgent", "openminds.latest.core.Person"],
            "startedBy",
            description="no description available",
            instructions="Add the agent that started this computation.",
        ),
        Property(
            "status",
            "openminds.latest.controlled_terms.ActionStatusType",
            "status",
            description="no description available",
            instructions="Enter the current status of this computation.",
        ),
        Property(
            "study_targets",
            [
                "openminds.latest.controlled_terms.AuditoryStimulusType",
                "openminds.latest.controlled_terms.BiologicalOrder",
                "openminds.latest.controlled_terms.BiologicalSex",
                "openminds.latest.controlled_terms.BreedingType",
                "openminds.latest.controlled_terms.CellCultureType",
                "openminds.latest.controlled_terms.CellType",
                "openminds.latest.controlled_terms.Disease",
                "openminds.latest.controlled_terms.DiseaseModel",
                "openminds.latest.controlled_terms.ElectricalStimulusType",
                "openminds.latest.controlled_terms.GeneticStrainType",
                "openminds.latest.controlled_terms.GustatoryStimulusType",
                "openminds.latest.controlled_terms.Handedness",
                "openminds.latest.controlled_terms.MolecularEntity",
                "openminds.latest.controlled_terms.OlfactoryStimulusType",
                "openminds.latest.controlled_terms.OpticalStimulusType",
                "openminds.latest.controlled_terms.Organ",
                "openminds.latest.controlled_terms.OrganismSubstance",
                "openminds.latest.controlled_terms.OrganismSystem",
                "openminds.latest.controlled_terms.Species",
                "openminds.latest.controlled_terms.SubcellularEntity",
                "openminds.latest.controlled_terms.TactileStimulusType",
                "openminds.latest.controlled_terms.TermSuggestion",
                "openminds.latest.controlled_terms.TissueSampleType",
                "openminds.latest.controlled_terms.UBERONParcellation",
                "openminds.latest.controlled_terms.VisualStimulusType",
                "openminds.latest.sands.CustomAnatomicalEntity",
                "openminds.latest.sands.ParcellationEntity",
                "openminds.latest.sands.ParcellationEntityVersion",
            ],
            "studyTarget",
            multiple=True,
            unique_items=True,
            min_items=1,
            description="Structure or function that was targeted within a study.",
            instructions="Add all study targets of this activity.",
        ),
        Property(
            "tags",
            str,
            "tag",
            multiple=True,
            unique_items=True,
            min_items=1,
            formatting="text/plain",
            description="no description available",
            instructions="Enter any custom tags for this computation.",
        ),
        Property(
            "techniques",
            "openminds.latest.controlled_terms.AnalysisTechnique",
            "technique",
            multiple=True,
            unique_items=True,
            min_items=1,
            description="Method of accomplishing a desired aim.",
            instructions="Add all analysis techniques that were used in this computation.",
        ),
        Property(
            "was_informed_by",
            [
                "openminds.latest.computation.DataAnalysis",
                "openminds.latest.computation.DataCopy",
                "openminds.latest.computation.GenericComputation",
                "openminds.latest.computation.ModelValidation",
                "openminds.latest.computation.Optimization",
                "openminds.latest.computation.Simulation",
                "openminds.latest.computation.Visualization",
            ],
            "wasInformedBy",
            description="no description available",
            instructions="Add another computation that sent data to this one during runtime.",
        ),
    ]

    def __init__(
        self,
        id=None,
        custom_property_sets=None,
        description=None,
        end_time=None,
        environment=None,
        inputs=None,
        launch_configuration=None,
        lookup_label=None,
        outputs=None,
        performed_by=None,
        recipe=None,
        resource_usages=None,
        score=None,
        start_time=None,
        started_by=None,
        status=None,
        study_targets=None,
        tags=None,
        techniques=None,
        was_informed_by=None,
    ):
        return super().__init__(
            id=id,
            custom_property_sets=custom_property_sets,
            description=description,
            end_time=end_time,
            environment=environment,
            inputs=inputs,
            launch_configuration=launch_configuration,
            lookup_label=lookup_label,
            outputs=outputs,
            performed_by=performed_by,
            recipe=recipe,
            resource_usages=resource_usages,
            score=score,
            start_time=start_time,
            started_by=started_by,
            status=status,
            study_targets=study_targets,
            tags=tags,
            techniques=techniques,
            was_informed_by=was_informed_by,
        )
