"""
Structured information on data originating from human/animal studies or simulations (version level).
"""

# this file was auto-generated!


from openminds.base import LinkedMetadata
from openminds.properties import Property


class DatasetVersion(LinkedMetadata):
    """
    Structured information on data originating from human/animal studies or simulations (version level).
    """

    type_ = "https://openminds.ebrains.eu/core/DatasetVersion"
    context = {"@vocab": "https://openminds.ebrains.eu/vocab/"}
    schema_version = "v1.0"

    properties = [
        Property(
            "accessibility",
            "openminds.v1.controlled_terms.ProductAccessibility",
            "accessibility",
            required=True,
            description="Level to which something is accessible to someone or something.",
            instructions="Add the accessibility of the data for this research product version.",
        ),
        Property(
            "authors",
            ["openminds.v1.core.Organization", "openminds.v1.core.Person"],
            "author",
            multiple=True,
            unique_items=True,
            min_items=1,
            required=True,
            description="Creator of a literary or creative work, as well as a dataset publication.",
            instructions="Add one or several authors (person or organization) that contributed to the production and publication of this research product version.",
        ),
        Property(
            "copyright",
            "openminds.v1.core.Copyright",
            "copyright",
            description="Exclusive and assignable legal right of an originator to reproduce, publish, sell, or distribute the matter and form of a creative work for a defined time period.",
            instructions="Add the copyright information of this research product version.",
        ),
        Property(
            "custodians",
            ["openminds.v1.core.Organization", "openminds.v1.core.Person"],
            "custodian",
            multiple=True,
            unique_items=True,
            min_items=1,
            required=True,
            description="The 'custodian' is a legal person who is responsible for the content and quality of the data, metadata, and/or code of a research product.",
            instructions="Add one or several custodians (person or organization) that are responsible for this research product version.",
        ),
        Property(
            "description",
            str,
            "description",
            formatting="text/markdown",
            multiline=True,
            required=True,
            description="Longer statement or account giving the characteristics of someone or something.",
            instructions="Enter a description (abstract) for this research product (max. 2000 characters, incl. spaces; no references).",
        ),
        Property(
            "developers",
            ["openminds.v1.core.Organization", "openminds.v1.core.Person"],
            "developer",
            multiple=True,
            unique_items=True,
            min_items=1,
            description="Legal person that creates or improves products or services (e.g., software, applications, etc.).",
            instructions="Add one or several developers (person or organization) that contributed to the code implementation of this research product version.",
        ),
        Property(
            "digital_identifier",
            "openminds.v1.core.DigitalIdentifier",
            "digitalIdentifier",
            required=True,
            description="Digital handle to identify objects or legal persons.",
            instructions="Add the globally unique and persistent digital identifier of this research product version.",
        ),
        Property(
            "ethics_assessment",
            "openminds.v1.controlled_terms.EthicsAssessment",
            "ethicsAssessment",
            required=True,
            description="Judgment about the applied principles of conduct governing an individual or a group.",
            instructions="Add the result of the ethics assessment of this dataset version.",
        ),
        Property(
            "full_documentation",
            "openminds.v1.core.DigitalIdentifier",
            "fullDocumentation",
            required=True,
            description="Non-abridged instructions, comments, and information for using a particular product.",
            instructions="Add the globally unique and persistent digital identifier of a full documentation of this research product version.",
        ),
        Property(
            "full_name",
            str,
            "fullName",
            formatting="text/plain",
            required=True,
            description="Whole, non-abbreviated name of something or somebody.",
            instructions="Enter a descriptive full name (title) for this research product version.",
        ),
        Property(
            "funding",
            "openminds.v1.core.Funding",
            "funding",
            multiple=True,
            unique_items=True,
            min_items=1,
            required=True,
            description="Money provided by a legal person for a particular purpose.",
            instructions="Add all funding information of this research product version.",
        ),
        Property(
            "has_alternative_versions",
            "openminds.v1.core.DatasetVersion",
            "hasAlternativeVersion",
            multiple=True,
            unique_items=True,
            min_items=1,
            description="no description available",
            instructions="Add all dataset versions that can be used alternatively to this dataset version.",
        ),
        Property(
            "has_supplement_versions",
            "openminds.v1.core.DatasetVersion",
            "hasSupplementVersion",
            multiple=True,
            unique_items=True,
            min_items=1,
            description="no description available",
            instructions="Add all dataset versions that supplement this dataset version.",
        ),
        Property(
            "homepage",
            str,
            "homepage",
            formatting="text/plain",
            description="Main website of something or someone.",
            instructions="Enter the internationalized resource identifier (IRI) to the homepage of this research product version.",
        ),
        Property(
            "is_new_version_of",
            "openminds.v1.core.DatasetVersion",
            "isNewVersionOf",
            description="Reference to a previous (potentially outdated) particular form of something.",
            instructions="Add the dataset version preceding this dataset version.",
        ),
        Property(
            "keywords",
            str,
            "keyword",
            multiple=True,
            unique_items=True,
            min_items=1,
            max_items=5,
            formatting="text/plain",
            description="Significant word or concept that are representative of something or someone.",
            instructions="Enter custom keywords to this research product version.",
        ),
        Property(
            "license",
            "openminds.v1.core.License",
            "license",
            required=True,
            description="Grant by a party to another party as an element of an agreement between those parties that permits to do, use, or own something.",
            instructions="Add the license of this research product version.",
        ),
        Property(
            "modalities",
            "openminds.v1.controlled_terms.Modality",
            "modality",
            multiple=True,
            unique_items=True,
            min_items=1,
            required=True,
            description="Classification according to a logical proposition in which something exists, is experienced or expressed.",
            instructions="Add all modalities in which the approaches used in this dataset version can be categorized in.",
        ),
        Property(
            "other_contributions",
            "openminds.v1.core.Contribution",
            "otherContribution",
            multiple=True,
            unique_items=True,
            min_items=1,
            description="Giving or supplying of something (such as money or time) as a part or share other than what is covered elsewhere.",
            instructions="Add the contributions for each involved person or organization going beyond being an author, custodian or developer of this research product version.",
        ),
        Property(
            "related_publications",
            "openminds.v1.core.DigitalIdentifier",
            "relatedPublication",
            multiple=True,
            unique_items=True,
            min_items=1,
            description="Reference to something that was made available for the general public to see or buy.",
            instructions="Add further publications besides the documentation (e.g. an original research article) providing the original context for the production of this research product version.",
        ),
        Property(
            "release_date",
            str,
            "releaseDate",
            formatting="text/plain",
            required=True,
            description="Fixed date on which a product is due to become or was made available for the general public to see or buy",
            instructions="Enter the date (actual or intended) of the first broadcast/publication of this research product version.",
        ),
        Property(
            "repository",
            "openminds.v1.core.FileRepository",
            "repository",
            required=True,
            description="Place, room, or container where something is deposited or stored.",
            instructions="Add the file repository of this research product version.",
        ),
        Property(
            "short_name",
            str,
            "shortName",
            formatting="text/plain",
            required=True,
            description="Shortened or fully abbreviated name of something or somebody.",
            instructions="Enter a short name (alias) for this research product version (max. 30 characters, no space).",
        ),
        Property(
            "types",
            "openminds.v1.controlled_terms.DatasetType",
            "type",
            multiple=True,
            unique_items=True,
            min_items=1,
            required=True,
            description="Distinct class to which a group of entities or concepts with similar characteristics or attributes belong to.",
            instructions="Add all data types (raw, derived or simulated) provided in this dataset version.",
        ),
        Property(
            "version_identifier",
            str,
            "versionIdentifier",
            formatting="text/plain",
            required=True,
            description="Term or code used to identify the version of something.",
            instructions="Enter the version identifier of this research product version.",
        ),
        Property(
            "version_innovation",
            str,
            "versionInnovation",
            formatting="text/markdown",
            multiline=True,
            description="Documentation on what changed in comparison to a previously published form of something.",
            instructions="Enter a short summary of the novelties/peculiarities of this research product version.",
        ),
    ]

    def __init__(
        self,
        id=None,
        accessibility=None,
        authors=None,
        copyright=None,
        custodians=None,
        description=None,
        developers=None,
        digital_identifier=None,
        ethics_assessment=None,
        full_documentation=None,
        full_name=None,
        funding=None,
        has_alternative_versions=None,
        has_supplement_versions=None,
        homepage=None,
        is_new_version_of=None,
        keywords=None,
        license=None,
        modalities=None,
        other_contributions=None,
        related_publications=None,
        release_date=None,
        repository=None,
        short_name=None,
        types=None,
        version_identifier=None,
        version_innovation=None,
    ):
        return super().__init__(
            id=id,
            accessibility=accessibility,
            authors=authors,
            copyright=copyright,
            custodians=custodians,
            description=description,
            developers=developers,
            digital_identifier=digital_identifier,
            ethics_assessment=ethics_assessment,
            full_documentation=full_documentation,
            full_name=full_name,
            funding=funding,
            has_alternative_versions=has_alternative_versions,
            has_supplement_versions=has_supplement_versions,
            homepage=homepage,
            is_new_version_of=is_new_version_of,
            keywords=keywords,
            license=license,
            modalities=modalities,
            other_contributions=other_contributions,
            related_publications=related_publications,
            release_date=release_date,
            repository=repository,
            short_name=short_name,
            types=types,
            version_identifier=version_identifier,
            version_innovation=version_innovation,
        )
