"""
Structured information on a brain atlas (version level).
"""

# this file was auto-generated!

from datetime import date
from openminds.base import IRI

from openminds.base import LinkedMetadata
from openminds.properties import Property


class BrainAtlasVersion(LinkedMetadata):
    """
    Structured information on a brain atlas (version level).
    """

    type_ = "https://openminds.ebrains.eu/sands/BrainAtlasVersion"
    context = {"@vocab": "https://openminds.ebrains.eu/vocab/"}
    schema_version = "v3.0"

    properties = [
        Property(
            "abbreviation",
            str,
            "abbreviation",
            formatting="text/plain",
            description="no description available",
            instructions="Enter the official abbreviation of this brain atlas version.",
        ),
        Property(
            "accessibility",
            "openminds.v3.controlled_terms.ProductAccessibility",
            "accessibility",
            required=True,
            description="Level to which something is accessible to someone or something.",
            instructions="Add the accessibility of the data for this research product version.",
        ),
        Property(
            "authors",
            ["openminds.v3.core.Consortium", "openminds.v3.core.Organization", "openminds.v3.core.Person"],
            "author",
            multiple=True,
            unique_items=True,
            min_items=1,
            description="Creator of a literary or creative work, as well as a dataset publication.",
            instructions="Add all parties that contributed to this brain atlas version as authors. Note that these authors will overwrite the author list provided for the overarching brain atlas.",
        ),
        Property(
            "coordinate_space",
            "openminds.v3.sands.CommonCoordinateSpaceVersion",
            "coordinateSpace",
            required=True,
            description="Two or three dimensional geometric setting.",
            instructions="Add the specific common coordinate space in which this brain atlas version exists.",
        ),
        Property(
            "copyright",
            "openminds.v3.core.Copyright",
            "copyright",
            description="Exclusive and assignable legal right of an originator to reproduce, publish, sell, or distribute the matter and form of a creative work for a defined time period.",
            instructions="Enter the copyright information of this research product version.",
        ),
        Property(
            "custodians",
            ["openminds.v3.core.Consortium", "openminds.v3.core.Organization", "openminds.v3.core.Person"],
            "custodian",
            multiple=True,
            unique_items=True,
            min_items=1,
            description="The 'custodian' is a legal person who is responsible for the content and quality of the data, metadata, and/or code of a research product.",
            instructions="Add all parties that fulfill the role of a custodian for the research product version (e.g., a research group leader or principle investigator). Custodians are typically the main contact in case of misconduct, obtain permission from the contributors to publish personal information, and maintain the content and quality of the data, metadata, and/or code of the research product version.",
        ),
        Property(
            "description",
            str,
            "description",
            formatting="text/markdown",
            multiline=True,
            description="Longer statement or account giving the characteristics of someone or something.",
            instructions="Enter a description (or abstract) of this research product version. Note that this version specific description will overwrite the description for the overarching dataset.",
        ),
        Property(
            "digital_identifier",
            ["openminds.v3.core.DOI", "openminds.v3.core.ISBN", "openminds.v3.core.RRID"],
            "digitalIdentifier",
            description="Digital handle to identify objects or legal persons.",
            instructions="Add the globally unique and persistent digital identifier of this research product version.",
        ),
        Property(
            "full_documentation",
            ["openminds.v3.core.DOI", "openminds.v3.core.File", "openminds.v3.core.WebResource"],
            "fullDocumentation",
            required=True,
            description="Non-abridged instructions, comments, and information for using a particular product.",
            instructions="Add the publication or file that acts as the full documentation of this research product version.",
        ),
        Property(
            "full_name",
            str,
            "fullName",
            formatting="text/plain",
            description="Whole, non-abbreviated name of something or somebody.",
            instructions="Enter a descriptive full name (or title) for this research product version. Note that this version specific full name will overwrite the full name for the overarching dataset.",
        ),
        Property(
            "funding",
            "openminds.v3.core.Funding",
            "funding",
            multiple=True,
            unique_items=True,
            min_items=1,
            description="Money provided by a legal person for a particular purpose.",
            instructions="Add all funding information of this research product version.",
        ),
        Property(
            "has_terminology",
            "openminds.v3.sands.ParcellationTerminologyVersion",
            "hasTerminology",
            required=True,
            description="no description available",
            instructions="Enter the specific parcellation terminology of this brain atlas version.",
        ),
        Property(
            "homepage",
            IRI,
            "homepage",
            description="Main website of something or someone.",
            instructions="Enter the internationalized resource identifier (IRI) to the homepage of this research product version.",
        ),
        Property(
            "how_to_cite",
            str,
            "howToCite",
            formatting="text/markdown",
            multiline=True,
            description="Preferred format for citing a particular object or legal person.",
            instructions="Enter the preferred citation text for this research product version. Leave blank if citation text can be extracted from the assigned digital identifier.",
        ),
        Property(
            "is_alternative_version_of",
            "openminds.v3.sands.BrainAtlasVersion",
            "isAlternativeVersionOf",
            multiple=True,
            unique_items=True,
            min_items=1,
            description="Reference to an original form where the essence was preserved, but presented in an alternative form.",
            instructions="Add all brain atlas versions that can be used alternatively to this brain atlas version.",
        ),
        Property(
            "is_new_version_of",
            "openminds.v3.sands.BrainAtlasVersion",
            "isNewVersionOf",
            description="Reference to a previous (potentially outdated) particular form of something.",
            instructions="Add the brain atlas version preceding this brain atlas version.",
        ),
        Property(
            "keywords",
            [
                "openminds.v3.controlled_terms.ActionStatusType",
                "openminds.v3.controlled_terms.AgeCategory",
                "openminds.v3.controlled_terms.AnalysisTechnique",
                "openminds.v3.controlled_terms.AnatomicalAxesOrientation",
                "openminds.v3.controlled_terms.AnatomicalIdentificationType",
                "openminds.v3.controlled_terms.AnatomicalPlane",
                "openminds.v3.controlled_terms.AnnotationCriteriaType",
                "openminds.v3.controlled_terms.AnnotationType",
                "openminds.v3.controlled_terms.AtlasType",
                "openminds.v3.controlled_terms.AuditoryStimulusType",
                "openminds.v3.controlled_terms.BiologicalOrder",
                "openminds.v3.controlled_terms.BiologicalProcess",
                "openminds.v3.controlled_terms.BiologicalSex",
                "openminds.v3.controlled_terms.BreedingType",
                "openminds.v3.controlled_terms.CellCultureType",
                "openminds.v3.controlled_terms.CellType",
                "openminds.v3.controlled_terms.ChemicalMixtureType",
                "openminds.v3.controlled_terms.Colormap",
                "openminds.v3.controlled_terms.ContributionType",
                "openminds.v3.controlled_terms.CranialWindowConstructionType",
                "openminds.v3.controlled_terms.CranialWindowReinforcementType",
                "openminds.v3.controlled_terms.CriteriaQualityType",
                "openminds.v3.controlled_terms.DataType",
                "openminds.v3.controlled_terms.DeviceType",
                "openminds.v3.controlled_terms.DifferenceMeasure",
                "openminds.v3.controlled_terms.Disease",
                "openminds.v3.controlled_terms.DiseaseModel",
                "openminds.v3.controlled_terms.EducationalLevel",
                "openminds.v3.controlled_terms.ElectricalStimulusType",
                "openminds.v3.controlled_terms.EthicsAssessment",
                "openminds.v3.controlled_terms.ExperimentalApproach",
                "openminds.v3.controlled_terms.FileBundleGrouping",
                "openminds.v3.controlled_terms.FileRepositoryType",
                "openminds.v3.controlled_terms.FileUsageRole",
                "openminds.v3.controlled_terms.GeneticStrainType",
                "openminds.v3.controlled_terms.GustatoryStimulusType",
                "openminds.v3.controlled_terms.Handedness",
                "openminds.v3.controlled_terms.Language",
                "openminds.v3.controlled_terms.Laterality",
                "openminds.v3.controlled_terms.LearningResourceType",
                "openminds.v3.controlled_terms.MeasuredQuantity",
                "openminds.v3.controlled_terms.MeasuredSignalType",
                "openminds.v3.controlled_terms.MetaDataModelType",
                "openminds.v3.controlled_terms.ModelAbstractionLevel",
                "openminds.v3.controlled_terms.ModelScope",
                "openminds.v3.controlled_terms.MolecularEntity",
                "openminds.v3.controlled_terms.OlfactoryStimulusType",
                "openminds.v3.controlled_terms.OperatingDevice",
                "openminds.v3.controlled_terms.OperatingSystem",
                "openminds.v3.controlled_terms.OpticalStimulusType",
                "openminds.v3.controlled_terms.Organ",
                "openminds.v3.controlled_terms.OrganismSubstance",
                "openminds.v3.controlled_terms.OrganismSystem",
                "openminds.v3.controlled_terms.PatchClampVariation",
                "openminds.v3.controlled_terms.PreparationType",
                "openminds.v3.controlled_terms.ProductAccessibility",
                "openminds.v3.controlled_terms.ProgrammingLanguage",
                "openminds.v3.controlled_terms.QualitativeOverlap",
                "openminds.v3.controlled_terms.SemanticDataType",
                "openminds.v3.controlled_terms.Service",
                "openminds.v3.controlled_terms.SetupType",
                "openminds.v3.controlled_terms.SoftwareApplicationCategory",
                "openminds.v3.controlled_terms.SoftwareFeature",
                "openminds.v3.controlled_terms.Species",
                "openminds.v3.controlled_terms.StimulationApproach",
                "openminds.v3.controlled_terms.StimulationTechnique",
                "openminds.v3.controlled_terms.SubcellularEntity",
                "openminds.v3.controlled_terms.SubjectAttribute",
                "openminds.v3.controlled_terms.TactileStimulusType",
                "openminds.v3.controlled_terms.Technique",
                "openminds.v3.controlled_terms.TermSuggestion",
                "openminds.v3.controlled_terms.Terminology",
                "openminds.v3.controlled_terms.TissueSampleAttribute",
                "openminds.v3.controlled_terms.TissueSampleType",
                "openminds.v3.controlled_terms.TypeOfUncertainty",
                "openminds.v3.controlled_terms.UBERONParcellation",
                "openminds.v3.controlled_terms.UnitOfMeasurement",
                "openminds.v3.controlled_terms.VisualStimulusType",
            ],
            "keyword",
            multiple=True,
            unique_items=True,
            min_items=1,
            description="Significant word or concept that are representative of something or someone.",
            instructions="Add all relevant keywords to this research product version either by adding controlled terms or by suggesting new terms.",
        ),
        Property(
            "license",
            "openminds.v3.core.License",
            "license",
            required=True,
            description="Grant by a party to another party as an element of an agreement between those parties that permits to do, use, or own something.",
            instructions="Add the license of this brain atlas version.",
        ),
        Property(
            "major_version_identifier",
            str,
            "majorVersionIdentifier",
            formatting="text/plain",
            description="no description available",
            instructions="Enter the identifier of the major version release this research product version belongs to.",
        ),
        Property(
            "ontology_identifier",
            IRI,
            "ontologyIdentifier",
            description="Term or code used to identify something or someone registered within a particular ontology.",
            instructions="Enter the internationalized resource identifier (IRI) to the related ontological term matching this brain atlas version.",
        ),
        Property(
            "other_contributions",
            "openminds.v3.core.Contribution",
            "otherContribution",
            multiple=True,
            unique_items=True,
            min_items=1,
            description="Giving or supplying of something (such as money or time) as a part or share other than what is covered elsewhere.",
            instructions="Add any other contributions to this research product version that are not covered under 'author'/'developer' or 'custodian'.",
        ),
        Property(
            "related_publications",
            [
                "openminds.v3.core.DOI",
                "openminds.v3.core.HANDLE",
                "openminds.v3.core.ISBN",
                "openminds.v3.core.ISSN",
                "openminds.v3.publications.Book",
                "openminds.v3.publications.Chapter",
                "openminds.v3.publications.ScholarlyArticle",
            ],
            "relatedPublication",
            multiple=True,
            unique_items=True,
            min_items=1,
            description="Reference to something that was made available for the general public to see or buy.",
            instructions="Add all further publications besides the full documentation that provide the original context for the production of this research product version (e.g., an original research article that used or produced the data of this research product version).",
        ),
        Property(
            "release_date",
            date,
            "releaseDate",
            required=True,
            description="Fixed date on which a product is due to become or was made available for the general public to see or buy",
            instructions="Enter the date (actual or intended) on which this research product version was first release, formatted as 'YYYY-MM-DD'.",
        ),
        Property(
            "repository",
            "openminds.v3.core.FileRepository",
            "repository",
            description="Place, room, or container where something is deposited or stored.",
            instructions="Add the file repository of this research product version.",
        ),
        Property(
            "short_name",
            str,
            "shortName",
            formatting="text/plain",
            required=True,
            description="Shortened or fully abbreviated name of something or somebody.",
            instructions="Enter a short name (or alias) for this research product version that could be used as a shortened display title (e.g., for web services with too little space to display the full name).",
        ),
        Property(
            "support_channels",
            str,
            "supportChannel",
            multiple=True,
            unique_items=True,
            min_items=1,
            formatting="text/plain",
            description="Way of communication used to interact with users or customers.",
            instructions="Enter all channels through which a user can receive support for handling this research product version.",
        ),
        Property(
            "type",
            "openminds.v3.controlled_terms.AtlasType",
            "type",
            description="Distinct class to which a group of entities or concepts with similar characteristics or attributes belong to.",
            instructions="Add the type of this brain atlas version.",
        ),
        Property(
            "used_specimens",
            [
                "openminds.v3.core.Subject",
                "openminds.v3.core.SubjectGroup",
                "openminds.v3.core.TissueSample",
                "openminds.v3.core.TissueSampleCollection",
            ],
            "usedSpecimen",
            multiple=True,
            unique_items=True,
            min_items=1,
            description="no description available",
            instructions="Add the specimen that was used for the creation of this brain atlas version.",
        ),
        Property(
            "version_identifier",
            str,
            "versionIdentifier",
            formatting="text/plain",
            required=True,
            description="Term or code used to identify the version of something.",
            instructions="Enter the version identifier of this research product version.",
        ),
        Property(
            "version_innovation",
            str,
            "versionInnovation",
            formatting="text/markdown",
            multiline=True,
            required=True,
            description="Documentation on what changed in comparison to a previously published form of something.",
            instructions="Enter a short description (or summary) of the novelties/peculiarities of this research product version in comparison to its preceding versions. If this research product version is the first version, you can enter the following disclaimer 'This is the first version of this research product'.",
        ),
    ]

    def __init__(
        self,
        id=None,
        abbreviation=None,
        accessibility=None,
        authors=None,
        coordinate_space=None,
        copyright=None,
        custodians=None,
        description=None,
        digital_identifier=None,
        full_documentation=None,
        full_name=None,
        funding=None,
        has_terminology=None,
        homepage=None,
        how_to_cite=None,
        is_alternative_version_of=None,
        is_new_version_of=None,
        keywords=None,
        license=None,
        major_version_identifier=None,
        ontology_identifier=None,
        other_contributions=None,
        related_publications=None,
        release_date=None,
        repository=None,
        short_name=None,
        support_channels=None,
        type=None,
        used_specimens=None,
        version_identifier=None,
        version_innovation=None,
    ):
        return super().__init__(
            id=id,
            abbreviation=abbreviation,
            accessibility=accessibility,
            authors=authors,
            coordinate_space=coordinate_space,
            copyright=copyright,
            custodians=custodians,
            description=description,
            digital_identifier=digital_identifier,
            full_documentation=full_documentation,
            full_name=full_name,
            funding=funding,
            has_terminology=has_terminology,
            homepage=homepage,
            how_to_cite=how_to_cite,
            is_alternative_version_of=is_alternative_version_of,
            is_new_version_of=is_new_version_of,
            keywords=keywords,
            license=license,
            major_version_identifier=major_version_identifier,
            ontology_identifier=ontology_identifier,
            other_contributions=other_contributions,
            related_publications=related_publications,
            release_date=release_date,
            repository=repository,
            short_name=short_name,
            support_channels=support_channels,
            type=type,
            used_specimens=used_specimens,
            version_identifier=version_identifier,
            version_innovation=version_innovation,
        )
